Documentation
¶
Index ¶
- func UpdateNameWithPrefixSource(i *Image) (string, error)
- type Image
- func (i Image) Elements() (string, string, string, error)
- func (i Image) ImageName() (string, error)
- func (i *Image) In(s []Image) bool
- func (i *Image) InP(s []*Image) bool
- func (i Image) IsEmpty() bool
- func (i *Image) ReplaceRegistry(new string) string
- func (i *Image) String() string
- func (i Image) TagOrDigest() (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func UpdateNameWithPrefixSource ¶
UpdateNameWithPrefixSource updates the image name with the registry prefix if PrefixSource is enabled.
Types ¶
type Image ¶
type Image struct {
Registry string
Repository string
Tag string
Digest string
UseDigest bool
Patch *bool
// contains filtered or unexported fields
}
func RefToImage ¶
RefToImage parses the reference string and returns an Image.
func (Image) IsEmpty ¶
IsEmpty determines if an image is empty (i.e., registry, repository, and name are empty).
func (*Image) ReplaceRegistry ¶
func (Image) TagOrDigest ¶
TagOrDigest returns a string representation of either the tag or digest.
Click to show internal directories.
Click to hide internal directories.